@@ -1,3 +1,8 @@
+from dataclasses import dataclass
+
+from remote_cmder.core.enums import ResponseType
+
+
 class Cmder:
     def __init__(self):
         self.__cmd_map = {}
@@ -13,3 +18,10 @@ class Cmder:
 
     def registers(self, cmd_map):
         self.__cmd_map.update(cmd_map)
+
+
+@dataclass
+class CmderResponse:
+    result: bool
+    data: bytes
+    type: ResponseType
